#
# spec file for package kitinerary
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0
%define kpim6_version 6.3.0

%bcond_without released
Name:           kitinerary
Version:        24.12.0
Release:        2.1
Summary:        Data model and extraction system for travel reservations
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# PATCH-FIX-UPSTREAM bcb009f56f8f1c9c0d1612a0ec9f581907b51534.patch -- Fix compilation against Poppler 25.01
Patch0:         https://github.com/KDE/kitinerary/commit/bcb009f56f8f1c9c0d1612a0ec9f581907b51534.patch
BuildRequires:  doxygen
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libphonenumber-devel
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  cmake(KF6CalendarCore) >= %{kf6_version}
BuildRequires:  cmake(KF6Contacts) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KPim6Mime) >= %{kpim6_version}
BuildRequires:  cmake(KPim6PkPass) >= %{kpim6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(ZXing)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(poppler-qt6)
BuildRequires:  pkgconfig(zlib)
Requires:       libKPim6Itinerary6 = %{version}

%description
Kitinerary is a library which provides a data model and a system to extract
information from travel reservations. The model can then be reused in other
applications.

%package -n libKPim6Itinerary6
Summary:        Data model and extraction system for travel reservations
Requires:       kitinerary >= %{version}
Obsoletes:      libKPim5Itinerary5-lang < %{version}

%description -n libKPim6Itinerary6
Kitinerary is a library which provides a data model and a system to extract
information from travel reservations. The model can then be reused in other
applications.
This package contains the kitinerary library.

%package devel
Summary:        Development files for kitinerary
Requires:       libKPim6Itinerary6 = %{version}
Requires:       cmake(KF6CalendarCore) >= %{kf6_version}
Requires:       cmake(KF6Contacts) >= %{kf6_version}
Requires:       cmake(KPim6Mime) >= %{kpim6_version}
Requires:       cmake(KPim6PkPass) >= %{kpim6_version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}

%description devel
This package contains all necessary include files and libraries needed
to build programs that use the kitinerary library.

%lang_package -n libKPim6Itinerary6

%prep
%autosetup -p1

%build

%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets -n libKPim6Itinerary6

%files
%{_kf6_debugdir}/org_kde_kitinerary.categories
%{_kf6_libexecdir}/kitinerary-extractor
%{_kf6_sharedir}/mime/packages/application-vnd-kde-itinerary.xml

%files -n libKPim6Itinerary6
%license LICENSES/*
%{_kf6_libdir}/libKPim6Itinerary.so.*

%files devel
%doc %{_kf6_qchdir}/KPim6Itinerary.*
%{_includedir}/KPim6/KItinerary/
%{_includedir}/KPim6/kitinerary/
%{_includedir}/KPim6/kitinerary_version.h
%{_kf6_cmakedir}/KPim6Itinerary/
%{_kf6_libdir}/libKPim6Itinerary.so

%files -n libKPim6Itinerary6-lang -f %{name}.lang

%changelog
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Add bcb009f56f8f1c9c0d1612a0ec9f581907b51534.patch -- Fix
  compilation against Poppler 25.01.
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * JsonLdImportFilter: Filter LodgingBusiness as a place
  * Update leoexpress.js
  * add: add Leo Express PkPass extractor
  * Add Dimedis Fairmate extractor
  * add: finish droplabs extractor
  * add: begin droplabs extractor
  * extractor for PKPass tickets from Droplabs
  * Handle French language European Sleeper seat reservations
  * Update RSP6 keys
  * add: Coloseum Ticket extractor
  * Fix pdf seats parsing for inoui trains
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * add: add luma extractor
  * fix according to reviews in MR
  * Update flixbus.js: remove console.logs
  * add: add parser for Flixbus.de pkpasses
  * Build Flatpak and static extractor against release branches
  * Update Flatpak dependencies
  * Update static build versions
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * Make Renfe barcode trigger pattern more strict (kde#494613)
  * Make Renfe extractor script more robust (kde#494617)
  * Add extractor script for Reisnordland ferries (kde#492096)
  * Relax MAV barcode matching pattern (kde#491403)
  * Add extractor script for EnTur PDF tickets (kde#490997)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Add extractor for Thai state railway tickets
  * Handle date format of NS RCT2 ticket barcodes
  * Add planway.com extractor script
  * Add VietJet Air extractor script
  * Add Spanish language plain text extraction patterns for booking.com
  * Sync OSM data types from KOSMIndoorMap
  * Make Renfe barcode trigger pattern more strict (kde#494613)
  * Extract passenger names from Renfe tickets when present
  * Make Renfe extractor script more robust (kde#494617)
  * Update Agoda extractor to handle confirmation mails in Spanish
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Handle missing train number in Trenitalia SSB barcodes
  * Handle German language variants of NH Hotels booking confirmations
  * Support membership number in German-language Eurostar (Thalys) tickets
  * Extract seat reservation data from SBB QR codes
  * Add Koleo ticket extractor script
  * eventim: Handle case when the event has no designated seats
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Add United Airlines reservations parser
  * sunnycars: Extract drop-off location, if available
  * Handle MAV ticket barcodes without a trip block
  * Fix latitude/longitude mixup
  * Add extractor script for (new?) Italo PDF tickets
  * Support French date/time format in BlablaBus tickets
  * Fix extraction of multi-page BlablaBus PDF tickets
  * Handle more Eurostar PDF layout variants
  * Add extractor script for Reisnordland ferries (kde#492096)
  * Unify the two DB ical extractor methods a bit
  * Add Reservix extractor
  * Try harder to decode names in VDV tickets
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Relax MAV barcode matching pattern (kde#491403)
  * Add extractor script for EnTur PDF tickets (kde#490997)
  * Fix IRCTC departure time extraction (kde#486495)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Add extractor for Georgian Railway (საქართველოს რკინიგზა)
  * If country name resolution failed, use the coordinate based lookup
  * Normalize whitespaces before doing anything with the country name
  * Add extractor for TCDD Taşımacılık (Turkish Railways)
  * Ignore creation date for PDFsharp PDFs
  * Add extractor script for Iberia reservation PDFs
  * Create airports as places rather than simple objects in the flight template
  * Add RCT2 IRT detection pattern for Snälltâget
  * Deal with Snälltâget having a typo in the U_TLAY type field
  * Accommodate TCDD's barcode padding
  * Make the 12go extractor more robust and handle more variants
  * Add basic hotels.com fallback extractors for emails without schema.org data
  * Add a sanity check for company capital notes in the price extractor
  * Extract RegioJet pkpass bus tickets
  * Add tobilet.pl event ticket extractor script
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Add tobilet.pl event ticket extractor script
  * Deal with Flixbus disruption notes
  * Fix wrong results for Flixbus multi-column seat information
  * Handle more Flixbus ticket token variants in JSON-LD data
  * Loosen the Flixbus extractor trigger pattern a bit
  * Special-case comparing Flixbus ticket tokens
  * Handle Air Asia booking email with departure terminals
  * Add generic extractor for ERA FCB customer card data
  * Decode ERA FCB CustomerCardData validity time ranges
  * Support Amadeus Cytric booking confirmations
  * Handle German language variants of Trenitalia tickets
  * Remove implausible time zones during post-processing
  * Fix filtering of invalid IATA BCBP child nodes
  * Make the Eurostar PDF extractor more robust against layout variations
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Make CFR extractor cover more layout variants
  * Add extractor script for international CFR PDF tickets
  * Fix IRCTC departure time extraction (kde#486495)
  * Extract information about train-bound SNCB RCT2 tickets
  * Restore disabled FreeBSD extractor tests
  * Use released Poppler for stable branch Flatpak builds
  * Fix extraction of cancellation URLs from Lufthansa pkpass files
  * Don't fail on non-ticket pages in Trenitalia PDFs
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Fix check for prices in SNCF extractor script (kde#485389)
  * Add extractor script for Eckerö Line ferry tickets (kde#481739)
  * Handle time quadruples in the generic boarding pass extractor (kde#481281)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Add extractor script for Eurostar's Thalys PDF ticket variant
  * Skip test with failing country detection on FreeBSD
  * Add extractor script for VR mobile PDF tickets
  * Consider berth number in VR ERA SSB ticket barcodes
  * Fix ERA SSB date conversion
  * Prettify data extracted from Eurostar ERA ELB barcodes
  * Add extractor script for UK national railway pkpass files
  * Don't override pkpass boarding pass child node results
  * Extract Eurostar pkpass tickets
  * Extract Eurostar PDF tickets
  * Actually add the new Finnair extractor script
  * fix: add amsbus e-ticket with reservation code only format
  * fix: added the SPDX Header for `amsbus.cz` extractor
  * Add `amsbus.cz` bus ticket extractor
  * Add Finnair e-ticket extractor script
  * fix: add SPDX headers
  * fix: add moongate extractor to the .qrc list
  * Add `moongate` event ticket extractor
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Handle German language European Sleeper seat reservations
  * Fix typo in include guard
  * Fix SNCF Carte Advantage token type
  * Fix instructions on how to get the continous Flatpak build
  * Check whether ERA FCB first name fields are set before using them
  * Update dependency versions for static builds
  * improve `salzbergwekr.de` extractor: address extraction from text
  * Add `salzbergwerk.de` tour reservation extractor
  * Use the KF6 Flatpak runtime
  * Significantly increase thresholds for PDF vector graphics barcodes
  * Normalize geo coordinate Place properties
  * Handle ti.to emails with iCal attachments correctly
  * Correctly update search offset for multi-leg National Express tickets
  * Add extractor script for Leo Express
  * Eventim: Drop debug output
  * Eventim: Also read event name from KEY_EVENTLINE
  * Add extractor script for Eckerö Line ferry tickets (kde#481739)
  * Handle ti.to PDF tickets as well
  * Add extractor script for ti.to pkpass files
  * Extract DB reservation iCal events
  * added Flibco parser in the bundled extractors list
  * Added Flibco parser
  * Handle another DB regional ERA TLB ticket variant with PLAI layout
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Handle another DB regional ERA TLB ticket variant with PLAI layout
  * Handle time quadruples in the generic boarding pass extractor (kde#481281)
  * Support the horizontally split double ticket layout for PV/Vivi
  * Extract seat information from Elron tickets
  * Make LTG Link extractor more robust against slight layout variations
  * Force-disable unity builds
  * Handle Carte Advantage with multiple validity periods
  * Don't set reservationNumber for Thalys ERA SSB barcodes to TCN
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Fix Motel One checkin time when running in a different timezone
  * Add Motel One pkpass extractor script
  * Add stand-alone filter condition for SAS itinerary PDFs
  * Handle another Flixbus Unicode station icon variant
  * Ignore ERA FCB UIC station codes in Germany
  * Use the entire UIC 918.3 station object, not just the identifier
  * Fix ERA FCB arrival time parsing
  * Support Dutch-language Eurostar (Thalys) tickets
  * Increase the maximum document size thresholds
  * Add basic support for 12go.asia PDFs
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Specify an encoding for libxml2 when reading from byte array data as well
  * Work around broken date/time values in booking.com mails without times
  * Make Uic9183Header externally usable
  * Adapt DB online import parser to also handle DB Next API replies
  * Adapt online ticket dumping tool to DB Next API changes
  * Fix booking.com address country extraction
  * Handle multi-line airport names in Qatar Airways tickets
  * Display non-ascii chars in PKP tickets
  * Add no-q event booking extractor
  * Sanity-check terminal names to deal with weird Iberia PDFs
  * Handle Iberia pkpass boarding passes and PDFs without a boarding group
  * Fix extracting Thalys tickets with a program membership used
  * Fix extraction from multi-line Pretix PDF tickets
  * Handle Pretix pkpass files with non-formatted date/time values
  * Handle Dutch language European Sleeper seat reservations
  * Handle Dutch language variants of European Sleeper tickets
  * Small optimizations for the static build
  * Update train station data from Wikidata
  * Fix train station country SPARQL query
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Fix several copy/paste errors in SortUtil::hasStart/EndTime()
  * Add bookingkit PDF extractor script
  * Handle departure/arrival/duration triples in generic extraction as well
  * Update clang-tidy settings to something more reasonable
  * Make the Amadeus PDF timestamp workaround a bit less specific
  * Correctly compare times with and without timezones when merging
  * Fix parsing newer UK railway PDF tickets
  * Deal with an alternative way to mark non-reservation RSP-6 tickets
  * Fix parsing GWR iCal attachments for multi-leg train trips
  * Manually merge international Renfe results
  * Unify reservation/ticket number extraction for Renfe/Ouigo ES barcodes
  * Move Renfe barcode documentation to the wiki
  * Add a workaround for fixing broken UIC 918.3 payloads in Renfe tickets
  * Sanity-check the RCT2 traveler name
  * Handle one more data format in RCT2 tickets
  * Try barcode decoding both on transformed and untranformed source images
  * Remove some excessive debug output
  * Extract un-styled Pretix PDF tickets
  * Extract multi-leg Renfe tickets correctly
  * Make train number matching slightly less strict
  * Merge the two ÖBB UIC 918.3 extractor scripts
  * Extract multi-leg ÖBB PDF tickets
  * Fix online import of unidirectional SNCF bookings (kde#474197)
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Also allow direct extraction from SNCF Secutix barcodes
  * Correctly update the search offset in the MAV extractor
  * Handle more cases of ZSSK network tickets
  * Correctly import buses from DB online tickets
  * Add Slovak Lines PDF ticket extractor script
  * Add premiumkino Apple Wallet pass extractor script
  * Handle more end of validtity variants in RCT2 tickets
  * Fall back to the second RCT2 title line if the first one is empty (kde#472916)
  * Handle Amtrak tickets with unreserved seats
  * Add British Airways boarding pass extractor script
  * Add extractor script for Aer Lingus PDF boarding passes
  * Increase upper aspect ratio limit for PDF417 barcodes
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Add extractor script for Aer Lingus PDF boarding passes
  * Increase upper aspect ratio limit for PDF417 barcodes
  * Support ZSSK network tickets
  * Improve ZSSK barcode trigger pattern
  * Add extractor script for Iberia PDF boarding passes
  * Add extractor script for KLM/Air France PDF boarding passes
  * Manually extract boarding time for Lufthansa PDF boarding passes
  * Determine trigger nodes also for ancestor filters
  * Skip generic flight time extraction if any of those is already present
  * Allow to match on the PDF document author field as well
  * Add DSB extractor script
  * Fix RSP-6 date/time parsing (kde#473326)
  * Fix wrong ticket token type prefixes in a few extractor scripts (kde#473325)
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Fix Spring Airlines multi-leg extraction
  * Add extractor script for Cinemaxx events
  * Run generic iCal extraction unconditionally in prior to extractors scripts
  * Track used extractor in the document node rather than the engine
  * Add cooltix.hu event ticket extractor script
  * Allow to filter against the PDF document creator field as well
  * Reduce the lower bound for 2D vector barcodes
  * Add LH extractor script to the qrc file
  * Extract discount program information from ERA FCB tickets
  * Make Aer Lingus booking number extraction more robust
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes to list here.
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Use a faster regex for matching Grimaldi Line passenger data
  * Add Color Line extractor script
  * Support onepagebooking PDFs as well
  * Expand the Fjord Line trigger expression to cover newer tickets
  * Treat any sequence of * characters as RCT2 empty marker
  * Accept also slightly larger ERA SSBv3 codes
  * Simplify Trenitalia extractor
  * Extract DJH membership card barcodes
  * Fix extraction of multi-page Trenitalia tickets
  * Improve handling of Flixbus train tickets
  * Add additional sanity checks for ERA SSBv2 tickets
  * Relax the SNCB barcode trigger pattern a bit
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Too many changes to list here.
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Too many changes to list here.
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
- Drop patch, merged upstream:
  * 0001-asn1-Fix-build-with-GCC-13-add-missing-cstdint-inclu.patch
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
- Add GCC 13 compatibility fix (boo#1201089):
  * 0001-asn1-Fix-build-with-GCC-13-add-missing-cstdint-inclu.patch
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
- Exclude test known to fail on Leap
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
- Drop patch, now upstream:
  * 0001-Support-ZXing-1.4.0.patch
* Wed Jul 20 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build with ZXing 1.4.0:
  * 0001-Support-ZXing-1.4.0.patch
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes to list here.
* Sun Mar 13 2022 Christophe Giboudeaux <christophe@krop.fr>
- Exclude test known to fail with kcontacts 5.92.
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Don't pass PDFDoc arguments that Poppler already has the same defaults for
  * Ignore more files for cppcheck that hang the latest version on the CI
  * Add basic Air France PDF ticket extractor
  * Reduce the lower size threshold for 2D barcodes
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Round up when converting vector bounding box to integers
  * Include the pen width in computing vector bounding boxes
  * Only consider rectangular strokes for the PDF vector barcode detection
  * Fix build against KF5.91+
  * Add extractor script for Skymark booking emails
  * Normalize flight numbers during post-processing
  * Make the same city detection consider more information
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Fixes for vitolus extractor
  * Extract UIC operator code from SNCF TER barcodes
  * Make proper json
  * Find more reservation number variants in SNCF TER PDF tickets
  * Add extractor script for Amtrak tickets
  * Make the VIA Rail extractor work both with a full PDF or just the barcode
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Exclude files that hang cppcheck on the CI
  * Enable new GitLab CI on stable branch.
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Add a new set of VDV certificates
  * Skip invalid VDV certificates rather than terminating the download
  * Add SPDX markers for the generated qrc file
  * Fix the Windows build
  * Recursively search for a context date from a context MIME node
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes to list here.
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Too many changes since 21.08.2, only listing bugfixes:
  * Handle English language MÁV ticket date formats (kde#444550)
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Correctly decode HTML MIME nodes which specify codecs in HTML and MIME
  * Handle US date formats in Accor hotel reservations
  * Add extractor for onepagebooking
  * Add extractor for Feratel cards
  * Fix extracting English language SNCF tickets
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Add Airdo confirmation mail extractor script
  * Extract SNCF Ouigo confirmation emails (kde#441361)
  * Extract Ryanair PDF boarding passes
  * Actually add the MAV extractor
  * Add basic MAV (Hungarian state railway) domestic ticket extractor
  * Add an alternative way of decoding RCT2 reservation data
  * Reproduce whitespaces a bit more correctly when layouting U_TLAY text
  * Let RCT2 type detection ignore whitespaces and support Hungarian IRTs
  * Add a watchdog timer to interrupt long running extractor scripts
  * Add Regionado pkpass extractor script
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- Changes since 21.07.90:
  * Fix build with poppler 21.8.0
  * Fix number to string deserialization for large integer numbers
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * The isspace/isctrl/etc functions require unsigned char as input
  * Remove unneeded MSVC utf-8 definition
  * Add event reservation extractor for ticketmaster.de
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes since 21.04.3, only listing bugfixes:
  * Handle SNCF TER booking confirmations (kde#439055)
  * Fix handling of asymmetric SNCF OUI retour tickets (kde#439061)
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Add extractor for Impfzentren Bayern
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Fix station name comparison for unbound train tickets
  * Fix single digit day date parsing in oui.sncf confirmation emails (kde#437854)
  * Improve handling of multi-leg and return tickets in Oui.sncf summary emails (kde#436976)
  * Fix off by one date in certain SNCF tickets
  * Apply the same departure day handling we have for flights also for trains
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Detect booking.com cancelations
  * Handle more variants of NH hotel booking confirmation emails
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * KItinerary doesn't build as a unity build, so don't even try that
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * Handle Accor reservation without a hotel phone number
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Handle yet another TER ticket variant
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * Consider horizontal flips in the PDF vector graphics transformation
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Work around another variant of invalid JSON
  * These tests don't need a QGuiApplication
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes to list here.
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * Be a bit less strict when applying the year from the context date
  * Guard against SNCF tickets having 1st/2nd leg barcode on 3rd leg page
  * Fix second leg class extraction from SNCF ticket barcodes
  * Extract English SNCF tickets
  * Avoid NaN comparisons
  * Require C++17
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Changes since 20.08.1:
  * Don't crash when trying to fix JSON-LD content
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- Changes since 20.07.90:
  * Silence an unused function warning
  * Fix class/struct declaration mismatch
  * Fix build with latest Poppler
  * Fix build with zxing 1.1.0 (kde#424853)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Fix the side-effects of openSUSE adding an Asia/Beijing timezone
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes to list here.
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Extract seat reservation information from Ouigo confirmations
  * Adapt to ZXing changing its library target name
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Fix includes. Try to make it compile under windows
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Fix extractor deduplication
  * Convert time to calendar timezone before taking the date
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Improve description for hotel booking ical events (kde#416444)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Handle language variants in the Vueling extractor
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * Fix merging of flight reservations with different IATA BCBP data
  * Deal with the German language variant of Trenitalia tickets
  * Move extractor engine capabilities string to the library
  * Add walking distance accuracy level for the location comparison
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Too many changes to list here.
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Too many changes to list here.
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Update knowledge base databases from Wikidata
  * Silence debug output
  * Do not fail on DB tickets with VDV barcodes
  * Make RegioJet date/time patterns more strict
  * Fix nullptr dereference when PDF loading fails
  * Add a RAII wrapper around Poppler's globalParams
  * Make the Poppler version checking a bit more scalable
  * Don't initialize MemoryCalendar with an invalid timezone
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes to list here.
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Better end time default for restaurant reservations without an end time
  * Fix compatibility with Poppler 0.82
* Thu Oct 17 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update build requirements, add missing Requires to devel package
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix UTC conversion during date/time parsing
  * Add another date format fallback for a new Lufthansa date format
  * Add unit test for JSON-LD date/time parsing
  * Fix date parsing in SNCF confirmation emails
  * QLatin1Literal => QLatin1String to fix compilation with Qt 5.14
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Adapt to KCalendarCore namespace change
  * Update Wikidata data tables for 19.08 release
  * Hotfix for ZXing master breaking pure QR code decoding for some reason
  * Fix another method name typo
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Check IATA BCBP input a bit more strictly (kde#407895)
  * Add German language support for the A&O hostel extractor
  * Handle line continuations in Deutsche Bahn tickets
  * More robust line continuation detection for the DB extractor
  * Keep the ticket token in the RCT2 extractor
  * Fix PNR extraction for some sort of DB/ÖBB cross-over ticket
  * PNR is optional in SNCF booking confirmations (kde#404451)
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Fix extraction of arrival/departure time for Brussels Airlines
  * Add airline IATA code as trigger criteria for Brussels Airlines too
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Don't block airport name disambiguation on the "international" fragment
  * Make the email parser handle all kinds of line breaks
  * Normalize all place names, not just those of airports
  * Extend Amadeus filter
  * Support one more Lufthansa variation of this
  * Support English BCD ical files too
  * Fix compile, Qt5Widgets_VERSION isn't defined, use Qt5Core_VERSION instead
  * Workaround qt5.13 bug
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Add missing comparison operators
  * Fix compatibility with Poppler 0.72
  * Fix FCM extractor for single digit flight numbers
  * Remove obsolete todo
  * Improve airport lookup by considering alternative umlaut transliterations
  * Cleanup airport name lookup code a bit
  * Fix flight calendar entries when IATA airport code is missing
  * Add arrival terminal property
  * Add Easyjet extractor
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * GBool -> bool
  * Relax leading space offset detection for international tickets
  * Auto-detect leading space in compact/international DB tickets
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Fri Sep  7 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Run the generic IATA BCBP extractor also for Vueling
  * Make the pdfdocumenttest pass without Poppler
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix binary Aztec barcode encoding for ticket tokens
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * None
* Thu Apr 12 2018 lbeltrame@kde.org
- Initial package
